import request from '@/utils/request'

// 查询工作票索引列表
export function listTag(query) {
  return request({
    url: '/invoice/tag/list',
    method: 'get',
    params: query
  })
}

// 查询工作票索引列表
export function listTagAll(query) {
  return request({
    url: '/invoice/tag/listAll',
    method: 'get',
    params: query
  })
}

// 查询工作票索引详细
export function getTag(id) {
  return request({
    url: '/invoice/tag/' + id,
    method: 'get'
  })
}

// 新增工作票索引
export function addTag(data) {
  return request({
    url: '/invoice/tag',
    method: 'post',
    data: data
  })
}

// 修改工作票索引
export function updateTag(data) {
  return request({
    url: '/invoice/tag',
    method: 'put',
    data: data
  })
}

// 修改报警开启状态
export function changeTagType(id, type) {
  const data = {
    id,
    type
  }
  return request({
    url: '/invoice/tag/changeTagType',
    method: 'put',
    data: data
  })
}

// 删除工作票索引
export function delTag(id) {
  return request({
    url: '/invoice/tag/' + id,
    method: 'delete'
  })
}

// 导出工作票索引
export function exportTag(query) {
  return request({
    url: '/invoice/tag/export',
    method: 'get',
    params: query
  })
}
